convert_header_value

Function convert_header_value 

pub fn convert_header_value(
    value: &HeaderValue,
    session: &Session,
    ctx: &Ctx,
) -> Option<HeaderValue>
Processes a HeaderValue that may contain a special dynamic variable (e.g., $host). It replaces the variable with its corresponding runtime value.