pub fn get_cookie_value<'a>(
req_header: &'a RequestHeader,
cookie_name: &str,
) -> Option<&'a str>Expand description
Parses the “Cookie” header to find the value of a specific cookie.
pub fn get_cookie_value<'a>(
req_header: &'a RequestHeader,
cookie_name: &str,
) -> Option<&'a str>Parses the “Cookie” header to find the value of a specific cookie.