pub fn get_req_header_value<'a>(
req_header: &'a RequestHeader,
key: &str,
) -> Option<&'a str>Expand description
A convenient helper to get a header value as a &str from a RequestHeader.
pub fn get_req_header_value<'a>(
req_header: &'a RequestHeader,
key: &str,
) -> Option<&'a str>A convenient helper to get a header value as a &str from a RequestHeader.