BackgroundTaskService

Struct BackgroundTaskService 

pub struct BackgroundTaskService { /* private fields */ }
A unified background service runner that can handle one or more named tasks.

Implementations

Source

impl BackgroundTaskService

pub fn new( name: &str, interval: Duration, tasks: Vec<(String, Box<dyn BackgroundTask>)>, ) -> Self

Creates a new service to run multiple background tasks.

pub fn new_single( name: &str, interval: Duration, task_name: &str, task: Box<dyn BackgroundTask>, ) -> Self

A convenience constructor for creating a service with a single task.

pub fn set_immediately(&mut self, immediately: bool)

Set whether the service should run immediately or wait for the interval

pub fn set_initial_delay(&mut self, initial_delay: Option<Duration>)

pub fn add_task(&mut self, task_name: &str, task: Box<dyn BackgroundTask>)

Add a task to the service This is useful for adding tasks to the service after it has been created

pub fn name(&self) -> String