Timing

Struct Timing 

pub struct Timing {
    pub created_at: Instant,
    pub connection_duration: u64,
    pub tls_handshake: Option<i32>,
    pub upstream_connect: Option<i32>,
    pub upstream_tcp_connect: Option<i32>,
    pub upstream_tls_handshake: Option<i32>,
    pub upstream_processing: Option<i32>,
    pub upstream_response: Option<i32>,
    pub upstream_connection_duration: Option<u64>,
    pub cache_lookup: Option<i32>,
    pub cache_lock: Option<i32>,
}
All timing-related metrics for the request lifecycle.

Fields

created_at: Instant

Timestamp in milliseconds when the request was created.

connection_duration: u64

The total duration of the client connection in milliseconds. May be large for reused connections.

tls_handshake: Option<i32>

The duration of the TLS handshake with the client in milliseconds.

upstream_connect: Option<i32>

The total duration to connect to the upstream server in milliseconds.

upstream_tcp_connect: Option<i32>

The duration of the TCP connection to the upstream server in milliseconds.

upstream_tls_handshake: Option<i32>

The duration of the TLS handshake with the upstream server in milliseconds.

upstream_processing: Option<i32>

The duration the upstream server took to process the request in milliseconds.

upstream_response: Option<i32>

The duration from sending the request to receiving the upstream response in milliseconds.

upstream_connection_duration: Option<u64>

The total duration of the upstream connection in milliseconds.

cache_lookup: Option<i32>

The duration of the cache lookup in milliseconds.

cache_lock: Option<i32>

The duration spent waiting for a cache lock in milliseconds.